@@ -226,7 +226,28 @@ See also the `profile' slot in the `browser' class.")
               :margin-top "2em")
             `("::selection"
               :color ,theme:on-action
-              :background-color ,theme:action)))
+              :background-color ,theme:action)
+            `(".mode-menu"
+              :overflow-x "scroll"
+              :white-space "nowrap"
+              :background-color ,theme:background-alt
+              :margin-left "-20px"
+              :margin-top "-20px"
+              :height "32px")
+            `(".mode-menu > button"
+              :color ,theme:on-secondary
+              :padding-left "8px"
+              :padding-right "8px"
+              :font-size "14px"
+              :border-radius "2px"
+              :margin "0"
+              :margin-right "12px"
+              :border "none"
+              :height "32px")
+            `(".mode-menu > .binding"
+              :background-color ,theme:secondary)
+            `(".mode-menu > .command"
+              :background-color ,theme:background-alt)))
    (buffer-delete-hook          ; TODO: Should we move this to `context-buffer'?
     (make-instance 'hook-buffer)
     :type hook-buffer
@@ -1452,10 +1473,10 @@ is listed first."
   "Toggle the focus between the current buffer and the current prompt buffer."
   (let ((prompt-buffer (current-prompt-buffer)))
     (if (prompt-buffer-p (focused-buffer))
-        (progn (set-current-buffer (current-buffer))
+        (prog1 (set-current-buffer (current-buffer))
                (ps-eval :buffer prompt-buffer
                  (setf (ps:@ (nyxt/ps:qs document "*") style opacity) "0.5")))
-        (progn (ffi-focus-prompt-buffer (current-window) prompt-buffer)
+        (prog1 (ffi-focus-prompt-buffer (current-window) prompt-buffer)
                (ps-eval :buffer prompt-buffer
                  (setf (ps:@ (nyxt/ps:qs document "*") style opacity) "1"))))))
 
