@@ -939,3 +939,19 @@ invoked via " (:code "flatpak-spawn --host <command> <command-args>") "."))))
           " now lists previously defined contexts.")
      (:li "Improve architecture of " (:nxref :class-name 'nyxt/mode/hint:hint-mode)
           " as to ensure that hints are shown for arbitrary URLs." ))))
+
+(define-version "3.11.0"
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li "Fix commands "
+          (:nxref :command 'reopen-last-buffer) " and "
+          (:nxref :command 'reopen-buffer) ".")
+     (:li "Fix performance issues related to "
+          (:nxref :class-name 'nyxt/mode/hint:hint-mode) ".")
+     (:li "Fix logic behind "
+          (:nxref :class-name 'prompter:source :slot 'prompter:actions-on-marks)
+          ".")))
+  (:nsection :title "UI/UX"
+    (:ul
+     (:li "Built-in modes and special pages have a dedicated menu area now. This menu
+allows access to common functions that are defined within the mode."))))
