@@ -93,6 +93,7 @@ See `nyxt::attribute-widths'.")
           :background-color ,theme:primary
           :color ,theme:on-primary
           :padding-left "10px"
+          :padding-right "8px"
           :line-height "28px")
         `("#prompt-input"
           :margin-right "-10px"
@@ -138,7 +139,9 @@ See `nyxt::attribute-widths'.")
           :color ,theme:on-action)
         `((:and .button :hover)
           :cursor "pointer"
-          :opacity 0.6)
+          :color ,theme:action)
+        `(".button:hover svg path"
+           :stroke ,theme:action-)
         `((:and .button (:or :visited :active))
           :color ,theme:background)
         `("#input"
@@ -162,9 +165,14 @@ See `nyxt::attribute-widths'.")
         `(".source-name"
           :background-color ,theme:secondary
           :color ,theme:on-secondary
-          :padding-left "5px"
+          :display "flex"
+          :justify-content "space-between"
+          :align-items "stretch"
           :line-height "24px"
           :border-radius "3px 0 0 0")
+        `(".source-name > div > button"
+          :padding "5px 4px 5px 4px"
+          :min-height "100%")
         `("#suggestions"
           :background-color ,theme:background
           :color ,theme:on-background
@@ -415,6 +423,8 @@ an integer."
     (when (prompter:suggestions source)
       (:table :class "source-content"
               (:colgroup
+               (when (prompter:enable-marks-p source)
+                 (:col :style "width: 25px"))
                (dolist (width (attribute-widths
                                source :dynamic-p (dynamic-attribute-width-p prompt-buffer)))
                  (:col :style (format nil "width: ~,2f%" (* 100 width)))))
@@ -423,6 +433,8 @@ an integer."
                                        (sera:single (prompter:active-attributes-keys source))))
                               "display:none;"
                               "display:revert;")
+                   (when (prompter:enable-marks-p source)
+                     (:th " "))
                    (loop for attribute-key in (prompter:active-attributes-keys source)
                          collect (:th (spinneret::escape-string attribute-key))))
               (loop
@@ -440,13 +452,14 @@ an integer."
                                 "selection")
                           :class (when (prompter:marked-p source (prompter:value suggestion))
                                    "marked")
-                          :onclick (when (mouse-support-p prompt-buffer)
-                                     (ps:ps
-                                       (cond
-                                         ((or (ps:chain window event ctrl-key)
-                                              (ps:chain window event shift-key))
+                          (when (prompter:enable-marks-p source)
+                            (:td
+                             (:input
+                              :type "checkbox"
+                              :checked (prompter:marked-p source (prompter:value suggestion))
+                              :onchange (ps:ps
                                           (nyxt/ps:lisp-eval
-                                           (:title "mark-this-suggestion"
+                                           (:title "unmark-this-suggestion"
                                             :buffer prompt-buffer)
                                            (prompter::set-current-suggestion
                                             prompt-buffer
@@ -455,32 +468,49 @@ an integer."
                                            (prompter::set-current-suggestion
                                             prompt-buffer
                                             (- cursor-index suggestion-index))
-                                           (prompt-render-suggestions prompt-buffer)))
-                                         ((ps:chain window event alt-key)
-                                          (nyxt/ps:lisp-eval
-                                           (:title "return-this-suggestion-with-another-action"
-                                            :buffer prompt-buffer)
-                                           (prompter::set-current-suggestion
-                                            prompt-buffer
-                                            (- suggestion-index cursor-index))
-                                           (uiop:symbol-call
-                                            :nyxt/prompt-buffer-mode :set-action-on-return
-                                            (nyxt::current-prompt-buffer))))
-                                         (t
-                                          (nyxt/ps:lisp-eval
-                                           (:title "return-this-suggestion"
-                                            :buffer prompt-buffer)
-                                           (prompter::set-current-suggestion
-                                            prompt-buffer
-                                            (- suggestion-index cursor-index))
-                                           (prompter:run-action-on-return
-                                            (nyxt::current-prompt-buffer)))))))
+                                           (prompt-render-suggestions prompt-buffer))))))
                           (loop for (nil attribute attribute-display)
-                                in (prompter:active-attributes suggestion :source source)
-                                collect (:td :title attribute
-                                             (if attribute-display
-                                                 (:raw attribute-display)
-                                                 attribute))))))))))
+                                  in (prompter:active-attributes suggestion :source source)
+                                collect (:td
+                                         :title attribute
+                                         :onclick (when (mouse-support-p prompt-buffer)
+                                                    (ps:ps
+                                                      (cond
+                                                        ((or (ps:chain window event ctrl-key)
+                                                             (ps:chain window event shift-key))
+                                                         (nyxt/ps:lisp-eval
+                                                          (:title "mark-this-suggestion"
+                                                           :buffer prompt-buffer)
+                                                          (prompter::set-current-suggestion
+                                                           prompt-buffer
+                                                           (- suggestion-index cursor-index))
+                                                          (prompter:toggle-mark prompt-buffer)
+                                                          (prompter::set-current-suggestion
+                                                           prompt-buffer
+                                                           (- cursor-index suggestion-index))
+                                                          (prompt-render-suggestions prompt-buffer)))
+                                                        ((ps:chain window event alt-key)
+                                                         (nyxt/ps:lisp-eval
+                                                          (:title "return-this-suggestion-with-another-action"
+                                                           :buffer prompt-buffer)
+                                                          (prompter::set-current-suggestion
+                                                           prompt-buffer
+                                                           (- suggestion-index cursor-index))
+                                                          (uiop:symbol-call
+                                                           :nyxt/prompt-buffer-mode :set-action-on-return
+                                                           (nyxt::current-prompt-buffer))))
+                                                        (t
+                                                         (nyxt/ps:lisp-eval
+                                                          (:title "return-this-suggestion"
+                                                           :buffer prompt-buffer)
+                                                          (prompter::set-current-suggestion
+                                                           prompt-buffer
+                                                           (- suggestion-index cursor-index))
+                                                          (prompter:run-action-on-return
+                                                           (nyxt::current-prompt-buffer)))))))
+                                         (if attribute-display
+                                             (:raw attribute-display)
+                                             attribute))))))))))
 
 (export 'prompt-render-suggestions)
 (define-generic prompt-render-suggestions ((prompt-buffer prompt-buffer))
@@ -491,39 +521,50 @@ This does not redraw the whole prompt buffer, use `prompt-render' for that."
          (last-source-index (1- (length sources))))
     (flet ((source->html (source)
              (spinneret:with-html-string
-               (:div :class "source"
-                     (:div :class "source-name"
-                           :style (if (and (hide-single-source-header-p prompt-buffer)
-                                           (sera:single sources))
-                                      "display:none;"
-                                      "display:revert")
-                           (:nbutton
-                             :text "↓"
-                             :title "Next source"
-                             :buffer prompt-buffer
-                             '(funcall (sym:resolve-symbol :next-source :command)))
-                           (:nbutton
-                             :text "↑"
-                             :title "Previous source"
-                             :buffer prompt-buffer
-                             '(funcall (sym:resolve-symbol :previous-source :command)))
-                           (:nbutton
-                             :text "⚙"
-                             :title "Toggle attributes display"
-                             :buffer prompt-buffer
-                             `(funcall (sym:resolve-symbol :toggle-attributes-display :command)
-                                       :source ,source))
-                           (prompter:name source)
-                           (if (prompter:hide-suggestion-count-p source)
-                               ""
-                               (suggestion-and-mark-count prompt-buffer
-                                                          (prompter:suggestions source)
-                                                          (prompter:marks source)
-                                                          :enable-marks-p (prompter:enable-marks-p source)))
-                           (if (prompter:ready-p source)
-                               ""
-                               "(In progress...)"))
-                     (:raw (render-attributes source prompt-buffer))))))
+               (:div.source
+                (:div.source-name
+                 :style (when (and (hide-single-source-header-p prompt-buffer)
+                                   (sera:single sources))
+                          "display:none")
+                 (:div
+                  (:nbutton
+                    :id "next-source"
+                    :text (:raw (gethash "down-arrow.svg" *static-data*))
+                    :title (format nil "Next source (~a)"
+                                   (binding-keys (sym:resolve-symbol :next-source
+                                                                     :command)
+                                                 :modes (modes prompt-buffer)))
+                    :buffer prompt-buffer
+                    '(funcall (sym:resolve-symbol :next-source :command)))
+                  (:nbutton
+                    :id "previous-source"
+                    :text (:raw (gethash "up-arrow.svg" *static-data*))
+                    :title (format nil "Previous source (~a)"
+                                   (binding-keys (sym:resolve-symbol :previous-source
+                                                                     :command)
+                                                 :modes (modes prompt-buffer)))
+                    :buffer prompt-buffer
+                    '(funcall (sym:resolve-symbol :previous-source :command)))
+                  (prompter:name source)
+                  (if (prompter:hide-suggestion-count-p source)
+                      ""
+                      (suggestion-and-mark-count prompt-buffer
+                                                 (prompter:suggestions source)
+                                                 (prompter:marks source)
+                                                 :enable-marks-p (prompter:enable-marks-p source)))
+                  (if (prompter:ready-p source) "" "(In progress...)"))
+                 (:div
+                  (:nbutton
+                    :id "toggle-attributes"
+                    :text (:raw (gethash "plus-minus.svg" *static-data*))
+                    :title (format nil "Toggle attributes display (~a)"
+                                   (binding-keys (sym:resolve-symbol 'toggle-attributes-display
+                                                                     :command)
+                                                 :modes (modes prompt-buffer)))
+                    :buffer prompt-buffer
+                    `(funcall (sym:resolve-symbol :toggle-attributes-display :command)
+                              :source ,source))))
+                (:raw (render-attributes source prompt-buffer))))))
       (ps-eval :buffer prompt-buffer
         (setf (ps:@ (nyxt/ps:qs document "#suggestions") |innerHTML|)
               (ps:lisp
